==> kubernetes-model-networking-5.3.1-sources.jar: io/fabric8/kubernetes/api/model/networking/v1beta1/IngressStatusFluentImpl.java <==
package io.fabric8.kubernetes.api.model.networking.v1beta1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.LoadBalancerStatus;

public class IngressStatusFluentImpl<A extends io.fabric8.kubernetes.api.model.networking.v1beta1.IngressStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.networking.v1beta1.IngressStatusFluent<A> {

    private LoadBalancerStatus loadBalancer;

    public IngressStatusFluentImpl() {
    }

    public IngressStatusFluentImpl(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressStatus instance) {
        this.withLoadBalancer(instance.getLoadBalancer()); 
    }

    public LoadBalancerStatus getLoadBalancer() {
        return this.loadBalancer;
    }

    public A withLoadBalancer(LoadBalancerStatus loadBalancer) {
        this.loadBalancer=loadBalancer; return (A) this;
    }

    public Boolean hasLoadBalancer() {
        return this.loadBalancer != null;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        IngressStatusFluentImpl that = (IngressStatusFluentImpl) o;
        if (loadBalancer != null ? !loadBalancer.equals(that.loadBalancer) :that.loadBalancer != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(loadBalancer,  super.hashCode());
    }

}

==> kubernetes-model-networking-5.7.0-sources.jar: io/fabric8/kubernetes/api/model/networking/v1beta1/IngressStatusFluentImpl.java <==
package io.fabric8.kubernetes.api.model.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.LoadBalancerStatus;

public class IngressStatusFluentImpl<A extends io.fabric8.kubernetes.api.model.networking.v1beta1.IngressStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.networking.v1beta1.IngressStatusFluent<A> {

    private io.fabric8.kubernetes.api.model.LoadBalancerStatus loadBalancer;

    public IngressStatusFluentImpl() {
    }

    public IngressStatusFluentImpl(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressStatus instance) {
        this.withLoadBalancer(instance.getLoadBalancer()); 
    }

    public io.fabric8.kubernetes.api.model.LoadBalancerStatus getLoadBalancer() {
        return this.loadBalancer;
    }

    public A withLoadBalancer(io.fabric8.kubernetes.api.model.LoadBalancerStatus loadBalancer) {
        this.loadBalancer=loadBalancer; return (A) this;
    }

    public java.lang.Boolean hasLoadBalancer() {
        return this.loadBalancer != null;
    }

    public boolean equals(java.lang.Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        IngressStatusFluentImpl that = (IngressStatusFluentImpl) o;
        if (loadBalancer != null ? !loadBalancer.equals(that.loadBalancer) :that.loadBalancer != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(loadBalancer,  super.hashCode());
    }

}
